@@ -481,6 +481,12 @@ def add_run_args(parser, add_workflow_argument=True):
 
     inpmanip_args = parser.add_argument_group("input manipulation")
 
+    inpmanip_args.add_argument(
+        "--strict-inputs",
+        help="Throw an error if inputs exist in the workflow that aren't used",
+        action="store_true",
+    )
+
     inpmanip_args.add_argument(
         "-r",
         "--recipe",
@@ -638,6 +644,12 @@ def add_run_args(parser, add_workflow_argument=True):
         "Janis is unable to appropriately manage locks on the central task database.",
     )
 
+    beta_args.add_argument(
+        "--dry-run",
+        action="store_true",
+        help="Setup the workflow, but don't actually run the workflow",
+    )
+
     parser.add_argument("extra_inputs", nargs=argparse.REMAINDER, default=[])
 
     return parser
@@ -812,7 +824,7 @@ def do_rm(args):
 
 
 def do_run(args):
-    jc = JanisConfiguration.initial_configuration(args.config)
+    jc = JanisConfiguration.initial_configuration(path=args.config)
 
     validation_reqs, batchrun_reqs = None, None
 
@@ -898,6 +910,8 @@ def do_run(args):
         container_override=parse_container_override_format(args.container_override),
         skip_digest_lookup=args.skip_digest_lookup,
         skip_digest_cache=args.skip_digest_cache,
+        dryrun=args.dry_run,
+        strict_inputs=args.strict_inputs,
     )
 
     Logger.info("Exiting")
@@ -917,7 +931,7 @@ def do_spider(args):
 def do_inputs(args):
 
     if args.config or args.recipe:
-        JanisConfiguration.initial_configuration(args.config)
+        JanisConfiguration.initial_configuration(path=args.config,)
 
     quality_type = None
 
