@@ -1,6 +1,6 @@
 import json
 from enum import Enum
-from typing import Tuple, Any, Dict, Union, List
+from typing import Tuple, Any, Dict, Union, List, Optional
 
 from janis_assistant.utils import stringify_value_or_array
 from janis_core.utils.logger import Logger
@@ -347,9 +347,9 @@ hsqldb.script_format=3
                     self.concurrent_job_limit = concurrent_job_limit
                     self.filesystems = filesystems
 
-                    self.runtime_attributes = (runtime_attributes or "").replace(
-                        "\n", "\\n"
-                    )
+                    self.runtime_attributes = runtime_attributes or ""  #     .replace(
+                    #     "\n", "\\n"
+                    # )
 
                     self.submit = submit
                     self.submit_docker = submit_docker
@@ -384,7 +384,36 @@ hsqldb.script_format=3
             key_map = {"actor_factory": "actor-factory"}
 
             @classmethod
-            def slurm(cls, call_caching_method: str = None):
+            def slurm(
+                cls,
+                jobqueues,
+                jobemail,
+                afternotokaycatch: bool = True,
+                call_caching_method: str = None,
+                sbatch: str = "sbatch",
+            ):
+
+                afternotokaycommand = ""
+                if afternotokaycatch:
+                    afternotokaycommand = f" && NTOKDEP=$({sbatch} --parsable --kill-on-invalid-dep=yes --dependency=afternotokay:$JOBID --wrap '{CromwellConfiguration.CATCH_ERROR_COMMAND}')"
+
+                emailextra = (
+                    f'--mail-user "{jobemail}" --mail-type END' if jobemail else ""
+                )
+
+                partition_string = ""
+                if jobqueues:
+                    partitions = (
+                        ",".join(jobqueues)
+                        if isinstance(jobqueues, list)
+                        else jobqueues
+                    )
+                    if partitions:
+                        partition_string = (
+                            f'-p ${{select_first([queue, "{partitions}"])}}'
+                        )
+                    else:
+                        partition_string = '${"-p" + queue}'
 
                 return cls(
                     actor_factory="cromwell.backend.impl.sfs.config.ConfigBackendLifecycleActorFactory",
@@ -395,19 +424,24 @@ Int? cpu = 1
 Int memory_mb = 3500
 String? docker
 String? queue
-""".strip(),
+""",
                         submit=f"""
-    jobname='{CromwellConfiguration.JOBNAME_TRANSFORM}'
-    sbatch \\
-        -J $jobname \\
-        -D ${{cwd}} \\
-        -o ${{out}} \\
-        -e ${{err}} \\
-        -t 0:${{duration}} \\
-        ${{"-p " + queue}} \\
-        ${{"-n " + cpu}} \\
-        --mem=${{memory_mb}} \\
-        --wrap "/usr/bin/env ${{job_shell}} ${{script}}" """,
+jobname={CromwellConfiguration.JOBNAME_TRANSFORM}
+JOBID=$({sbatch} \\
+    --parsable \\
+    --job-name $jobname \\
+    --chdir ${{cwd}} \\
+    --output ${{cwd}}/execution/stdout \\
+    --error ${{cwd}}/execution/stderr \\
+    --mem ${{memory_mb}} \\
+    --cpus-per-task ${{select_first([cpu, 1])}} \\
+    {partition_string} \\
+    --time '0:${{duration}}' \\
+    {emailextra} \\
+    --wrap "/usr/bin/env ${{job_shell}} ${{script}}") \\
+    {afternotokaycommand} \\
+    && echo Submitted batch job $JOBID
+""",
                         kill="scancel ${job_id}",
                         check_alive="scontrol show job ${job_id}",
                         job_id_regex="Submitted batch job (\\d+).*",
@@ -420,67 +454,73 @@ String? queue
             @classmethod
             def slurm_singularity(
                 cls,
-                singularityloadinstructions,
-                singularitycontainerdir,
-                buildinstructions,
-                jobemail,
-                jobqueues,
+                singularitycontainerdir: str,
+                jobqueues: Optional[Union[str, List[str]]] = None,
+                buildinstructions: Optional[str] = None,
+                jobemail: Optional[str] = None,
+                singularityloadinstructions: Optional[str] = None,
                 afternotokaycatch: bool = True,
                 call_caching_method: str = None,
+                sbatch: str = "sbatch",
             ):
-                slurm = cls.slurm(call_caching_method=call_caching_method)
+                slurm = cls.slurm(
+                    jobemail=jobemail,
+                    jobqueues=jobqueues,
+                    afternotokaycatch=afternotokaycatch,
+                    call_caching_method=call_caching_method,
+                    sbatch=sbatch,
+                )
 
                 afternotokaycommand = ""
                 if afternotokaycatch:
-                    afternotokaycommand = f" && NTOKDEP=$(sbatch --parsable --kill-on-invalid-dep=yes --dependency=afternotokay:$JOBID --wrap '{CromwellConfiguration.CATCH_ERROR_COMMAND}')"
+                    afternotokaycommand = f" && NTOKDEP=$({sbatch} --parsable --kill-on-invalid-dep=yes --dependency=afternotokay:$JOBID --wrap '{CromwellConfiguration.CATCH_ERROR_COMMAND}')"
 
-                partitions = (
-                    ",".join(jobqueues) if isinstance(jobqueues, list) else jobqueues
-                )
-                if partitions:
-                    partition_string = f'${{if defined(queue) then ("-p" + queue) else "-p {partitions}"}}'
-                else:
-                    partition_string = '${"-p" + queue}'
+                partition_string = ""
+                if jobqueues:
+                    partitions = (
+                        ",".join(jobqueues)
+                        if isinstance(jobqueues, list)
+                        else jobqueues
+                    )
+                    if partitions:
+                        partition_string = (
+                            f'-p ${{select_first([queue, "{partitions}"])}}'
+                        )
+                    else:
+                        partition_string = '${"-p" + queue}'
 
                 emailextra = (
-                    f"--mail-user {jobemail} --mail-type END" if jobemail else ""
+                    f'--mail-user "{jobemail}" --mail-type END' if jobemail else ""
                 )
 
-                slurm.config.runtime_attributes = """\
-Int duration
-Int? cpu = 1
-Int memory_mb = 3500
-String? docker
-String? queue
-"""
                 # slurm.config.submit = None
                 slurm.config.submit_docker = f"""\
-            {singularityloadinstructions or ''}
+{singularityloadinstructions or ''}
 
-            docker_subbed=$(sed -e 's/[^A-Za-z0-9._-]/_/g' <<< ${{docker}})
-            image={singularitycontainerdir}/$docker_subbed.sif
-            lock_path={singularitycontainerdir}/$docker_subbed.lock
+docker_subbed=$(sed -e 's/[^A-Za-z0-9._-]/_/g' <<< ${{docker}})
+image={singularitycontainerdir}/$docker_subbed.sif
+lock_path={singularitycontainerdir}/$docker_subbed.lock
 
-            if [ ! -f "$image" ]; then
-              {buildinstructions}
-            fi
+if [ ! -f "$image" ]; then
+  {buildinstructions or 'singularity pull $image docker://${docker}'}
+fi
 
-            # Submit the script to SLURM
-            jobname={CromwellConfiguration.JOBNAME_TRANSFORM}
-            JOBID=$(sbatch \\
-                --parsable \\
-                -J $jobname \\
-                --mem=${{memory_mb}} \\
-                --cpus-per-task ${{select_first([cpu, 1])}} \\
-                {partition_string} \\
-                -D ${{cwd}} \\
-                -o ${{cwd}}/execution/stdout \\
-                -e ${{cwd}}/execution/stderr \\
-                -t '0:${{duration}}' \\
-                {emailextra} \\
-                --wrap "singularity exec --bind ${{cwd}}:${{docker_cwd}} $image ${{job_shell}} ${{docker_script}}") \\
-                {afternotokaycommand} \\
-                && echo Submitted batch job $JOBID
+# Submit the script to SLURM
+jobname={CromwellConfiguration.JOBNAME_TRANSFORM}
+JOBID=$({sbatch} \\
+    --parsable \\
+    --job-name $jobname \\
+    --mem ${{memory_mb}} \\
+    --cpus-per-task ${{select_first([cpu, 1])}} \\
+    {partition_string} \\
+    --chdir ${{cwd}} \\
+    --output ${{cwd}}/execution/stdout \\
+    --error ${{cwd}}/execution/stderr \\
+    --time '0:${{duration}}' \\
+    {emailextra} \\
+    --wrap "singularity exec --bind ${{cwd}}:${{docker_cwd}} $image ${{job_shell}} ${{docker_script}}") \\
+    {afternotokaycommand} \\
+    && echo Submitted batch job $JOBID
             """
                 return slurm
 
@@ -764,6 +804,51 @@ String? queue
             "blacklist_cache": "blacklist-cache",
         }
 
+    class Services(Serializable):
+        class MetadataService(Serializable):
+            def __init__(
+                self,
+                summary_refresh_interval: Optional[Union[str, int]] = None,
+                summary_refresh_limit: Optional[int] = None,
+                read_row_number_safety_threshold: Optional[int] = None,
+                db_batch_size: Optional[int] = None,
+                db_flush_rate: Optional[int] = None,
+            ):
+                """
+                
+                :param summary_refresh_interval: Set this value to "Inf" to turn off metadata summary refresh.  The default value is currently "1 second"
+                :param summary_refresh_limit: maximum number of metadata rows to be considered per summarization cycle
+                :param db_batch_size:
+                :param db_flush_rate:
+                """
+                self.summary_refesh_interval = summary_refresh_interval
+                self.summary_refresh_limit = summary_refresh_limit
+                self.read_row_number_safety_threshold = read_row_number_safety_threshold
+                self.db_batch_size = db_batch_size
+                self.db_flush_rate = db_flush_rate
+
+            key_map = {
+                "summary_refresh_interval": "metadata-summary-refresh-interval",
+                "summary_refresh_limit": "metadata-summary-refresh-limit",
+                "db_batch_size": "db-batch-size",
+                "db_flush_rate": "db-flush-rate",
+                "read_row_number_safety_threshold": "metadata-read-row-number-safety-threshold",
+            }
+
+            def to_dict(self):
+                return {
+                    "class": "cromwell.services.metadata.impl.MetadataServiceActor",
+                    "config": super().to_dict(),
+                }
+
+        def __init__(self, metadata: MetadataService, **kwargs):
+            self.__d = {}
+            self.__d.update(kwargs)
+            self.__d["MetadataService"] = metadata
+
+        def to_dict(self):
+            return self.__d
+
     def __init__(
         self,
         webservice: Webservice = None,
@@ -775,6 +860,7 @@ String? queue
         docker: Docker = Docker.default(),
         cache: CallCaching = None,
         aws=None,
+        services: Services = None,
         additional_params=None,
     ):
         if webservice is not None and isinstance(
