@@ -67,6 +67,7 @@ class Cromwell(Engine):
         config: CromwellConfiguration = None,
         config_path=None,
         execution_dir: str = None,
+        polling_interval: Optional[int] = None,
     ):
 
         super().__init__(
@@ -98,6 +99,16 @@ class Cromwell(Engine):
         # Last contacted is used to determine
         self.last_contacted = None
         self.timeout = 10  # minutes
+        if polling_interval is not None:
+            polling_interval = int(polling_interval)
+            if polling_interval < 3:
+                Logger.warn(
+                    f"The polling interval for Cromwell was {polling_interval} seconds, but Janis "
+                    f"requires > 3 seconds to ensure metadata is processed correctly"
+                )
+                polling_interval = None
+
+        self.polling_interval = polling_interval
         self._start_time = None
 
         self.connectionerrorcount = 0
@@ -170,6 +181,8 @@ class Cromwell(Engine):
         """
         Get poll interval in SECONDS
         """
+        if self.polling_interval is not None:
+            return self.polling_interval
 
         max_poll = 60  # seconds
         min_poll = 5  # seconds
@@ -268,18 +281,19 @@ class Cromwell(Engine):
             self._process.stdout.readline, "b"
         ):  # replace '' with b'' for Python 3
 
-            line = None if not c else c.decode("utf-8").rstrip()
-
-            rc = self._process.poll()
-            if rc is not None:
-                critical_suffix = f"Last received message '{line}'. "
-                Logger.critical(
-                    f"Cromwell has exited with rc={rc}. {critical_suffix}The last lines of the logfile ({self.logfile}):"
-                )
-                Logger.critical(tail(self._logfp, 10))
-                return False
+            line = None
+            if c:
+                line = c.decode("utf-8").rstrip()
 
             if not line:
+                rc = self._process.poll()
+                if rc is not None:
+                    critical_suffix = f"Last received message '{line}'. "
+                    Logger.critical(
+                        f"Cromwell has exited with rc={rc}. {critical_suffix}The last lines of the logfile ({self.logfile}):"
+                    )
+                    Logger.critical("".join(tail(self._logfp, 10)))
+                    return False
                 continue
 
             if self._logfp and not self._logfp.closed:
@@ -319,7 +333,7 @@ class Cromwell(Engine):
             "Cromwell exited with rc = {rc}, check the engine log for more information"
         )
         self.process_id = None
-        self.process = None
+        self._process = None
 
     def stop_engine(self):
         if self._logger:
@@ -486,8 +500,8 @@ class Cromwell(Engine):
         if fromenv and os.path.exists(fromenv):
             return fromenv
 
-        potentials = reversed(
-            sorted(glob(os.path.join(man.configdir + "cromwell-*.jar")))
+        potentials = list(
+            reversed(sorted(glob(os.path.join(man.configdir, "cromwell-*.jar"))))
         )
 
         valid_paths = [p for p in potentials if os.path.exists(p)]
@@ -690,6 +704,7 @@ class Cromwell(Engine):
         try:
             r = request.urlopen(url)
             self.connectionerrorcount = 0
+            self.metadataerrorcount = 0
 
             self.last_contacted = datetime.now()
 
@@ -704,18 +719,28 @@ class Cromwell(Engine):
                 # Usually means Cromwell hasn't loaded properly yet
                 return None
 
+            er_message = "An unexpected error occurred: " + str(e)
             try:
                 body = e.read().decode()
                 jsonobj = json.loads(body) if body else {}
-                message = jsonobj.get(
-                    "message", "An unexpected error occurred: " + str(e)
-                )
-                Logger.warn("Response when getting Cromwell metadata: " + str(message))
+                message = jsonobj.get("message")
+                if message:
+                    er_message = f"Response when getting Cromwell metadata: {message}"
             except Exception as ee:
-                Logger.warn(str(e))
+                er_message = (
+                    f"An additional error occurred while trying to determine the reason"
+                    f" why Cromwell metadata failed (internal: {repr(ee)}): {repr(e)})"
+                )
             finally:
+                Logger.warn("Couldn't get Cromwell metadata: " + str(er_message))
+                self.metadataerrorcount += 1
+                if self.metadataerrorcount > 5:
+                    # we could check the status of the workflow, or we could just suspend it really
+                    # 5 consecutive errors
+                    raise e
                 return None
-        except request.URLError as e:
+
+        except (request.URLError, ConnectionResetError) as e:
             self.connectionerrorcount += 1
             if (
                 datetime.now() - self.last_contacted
@@ -724,10 +749,10 @@ class Cromwell(Engine):
                     "last_updated_threshold"
                 )  # idk, pick a number
                 return None
-            if self.connectionerrorcount > 5:
+            if self.connectionerrorcount > 15:
                 raise e
             else:
-                Logger.warn("Error connecting to cromwell instance: " + str(e))
+                Logger.warn("Error connecting to cromwell instance: " + repr(e))
             return None
 
     def metadata(self, identifier, expand_subworkflows=True) -> Optional[RunModel]:
