@@ -56,19 +56,26 @@ class JanisConfiguration(NoAttributeErrors):
         return JanisConfiguration._managed
 
     @staticmethod
-    def initial_configuration(potential_paths: Optional[Union[str, List[str]]]):
+    def initial_configuration(
+        path: Optional[str], potential_paths: Optional[Union[str, List[str]]] = None
+    ):
 
         paths_to_check = []
-        if potential_paths:
-            if isinstance(potential_paths, list):
-                paths_to_check.extend(potential_paths)
-            else:
-                paths_to_check.append(potential_paths)
+        if path is not None:
+            if not os.path.exists(path):
+                raise Exception(f"Couldn't find Janis configuration at path: {path}")
+            paths_to_check = [path]
+        else:
+            if potential_paths:
+                if isinstance(potential_paths, list):
+                    paths_to_check.extend(potential_paths)
+                else:
+                    paths_to_check.append(potential_paths)
 
-        default_path = EnvVariables.config_path.resolve(False)
-        if default_path:
-            paths_to_check.append(default_path)
-        paths_to_check.append(EnvVariables.config_path.default())
+            default_path = EnvVariables.config_path.resolve(False)
+            if default_path:
+                paths_to_check.append(default_path)
+            paths_to_check.append(EnvVariables.config_path.default())
 
         for p in paths_to_check:
             if p:
@@ -131,6 +138,7 @@ class JanisConfiguration(NoAttributeErrors):
             UseManagedMySqlInstance = "should_manage_mysql"
             UseDatabase = "use_database"
             AdditionalParameters = "additional_params"  # string or list of strings
+            PollingInterval = "polling_interval"
 
         def __init__(self, d: dict, default: dict):
             d = d if d else {}
@@ -147,6 +155,10 @@ class JanisConfiguration(NoAttributeErrors):
                 d, self.Keys.Memory, default
             )
 
+            self.polling_interval = JanisConfiguration.get_value_for_key(
+                d, self.Keys.PollingInterval, default
+            )
+
             self.call_caching_method = JanisConfiguration.get_value_for_key(
                 d, self.Keys.CallCachingMethod, default
             )
@@ -354,6 +366,7 @@ class JanisConfiguration(NoAttributeErrors):
         class Keys(HashableEnum):
             # Events = "events"   # All events currently
             Email = "email"
+            FromEmail = "fromEmail"
             MailProgram = "mail_program"
             # Slack = "slack"     # unused
 
@@ -363,6 +376,9 @@ class JanisConfiguration(NoAttributeErrors):
             self.email = JanisConfiguration.get_value_for_key(
                 d, self.Keys.Email, default
             )
+            self.from_email = JanisConfiguration.get_value_for_key(
+                d, self.Keys.FromEmail, default
+            )
 
             self.mail_program = JanisConfiguration.get_value_for_key(
                 d, self.Keys.MailProgram, default
@@ -485,7 +501,8 @@ class JanisConfiguration(NoAttributeErrors):
                 JanisConfiguration.JanisConfigurationTemplate.Keys.Id: "local"
             },
             JanisConfiguration.Keys.Notifications: {
-                JanisConfiguration.JanisConfigurationNotifications.Keys.Email: None
+                JanisConfiguration.JanisConfigurationNotifications.Keys.Email: None,
+                JanisConfiguration.JanisConfigurationNotifications.Keys.FromEmail: "janis-noreply@petermac.org",
             },
             JanisConfiguration.Keys.RunInBackground: None,
             JanisConfiguration.Keys.CallCachingEnabled: True,
