@@ -430,14 +430,15 @@ class WorkflowManager:
         else:
             self.poll_stored_metadata_with_clear(**kwargs)
 
-    def get_meta_call(self):
+    def get_meta_call(self) -> Tuple[Optional[SubmissionModel], bool]:
         meta = self.database.get_metadata()
         if meta is None:
             return None, False
 
         return (
             meta,
-            meta and all(m.status in TaskStatus.final_states() for m in meta.runs),
+            meta is not None
+            and all(m.status in TaskStatus.final_states() for m in meta.runs),
         )
 
     def poll_stored_metadata_with_clear(self, seconds=3, **kwargs):
@@ -446,18 +447,43 @@ class WorkflowManager:
 
             # We won't clear the screen if we haven't printed (first loop) and it's finished
             has_printed = False
+            last_updated = None
+            metadata_skips = 0
             while not is_finished:
                 meta, is_finished = self.get_meta_call()
                 if meta:
-                    if has_printed or not is_finished:
-                        try:
-                            call("clear")
-                        except Exception as e:
-                            Logger.log(
-                                f"We got a subprocess error when clearing the screen: {repr(e)}"
-                            )
-                    print(meta.format(**kwargs))
-                    has_printed = True
+
+                    has_updated = (
+                        last_updated is not None
+                        and bool(meta.runs)
+                        and meta.runs[0].last_updated is not None
+                        and meta.runs[0].last_updated > last_updated
+                    )
+                    ignore_has_updated = metadata_skips > 20
+                    is_running = not is_finished
+                    if not has_printed or (
+                        is_running and (has_updated or ignore_has_updated)
+                    ):
+                        metadata_skips = 0
+                        if meta.runs:
+                            last_updated = meta.runs[0].last_updated
+
+                        # only clear the screen if we haven't updated
+                        if has_printed or is_running:
+
+                            try:
+                                call("clear")
+                            except Exception as e:
+                                Logger.log(
+                                    f"We got a subprocess error when clearing the screen: {repr(e)}"
+                                )
+                        print(meta.format(**kwargs))
+                        has_printed = True
+                    else:
+                        Logger.log(
+                            f"No job status updates were find, we'll wait another {seconds} seconds"
+                        )
+                        metadata_skips += 1
 
                 if seconds < 0:
                     is_finished = True
@@ -551,8 +577,18 @@ class WorkflowManager:
             self.remove_semaphores()
 
             logsdir = self.get_path_for_component(self.WorkflowManagerPath.logs)
+            wid = self.submission_id
+            debugpath = os.path.join(logsdir, f"janis-monitor.{wid}.debug.log")
+            infopath = os.path.join(logsdir, f"janis-monitor.{wid}.info.log")
+            warnpath = os.path.join(logsdir, f"janis-monitor.{wid}.warn.log")
 
-            Logger.set_write_location(os.path.join(logsdir, "janis-monitor.log"))
+            Logger.info("Logging debug information to: " + str(debugpath))
+
+            Logger.WRITE_LEVELS = {
+                LogLevel.DEBUG: (debugpath, open(debugpath, "a")),
+                LogLevel.INFO: (infopath, open(infopath, "a")),
+                LogLevel.WARNING: (warnpath, open(warnpath, "a")),
+            }
 
             # in case anything relies on CD, we'll throw it into janis/execution
             os.chdir(self.get_path_for_component(self.WorkflowManagerPath.execution))
@@ -622,7 +658,7 @@ class WorkflowManager:
 
             err = traceback.format_exc()
             Logger.critical(
-                f"A fatal error occurred while monitoring workflow = '{self.submission_id}', exiting: {e}: {err}"
+                f"A fatal error occurred while monitoring workflow = '{self.submission_id}', exiting: {e}:\n {err}"
             )
 
             try:
